@@ -30,7 +30,6 @@
 #include "gnet.h"
 
 static GConfClient *client = NULL;
-static GConfChangeSet *changeset;
 
 typedef enum {
 	CDDB_ACCESS_READWRITE,
@@ -99,8 +98,7 @@ destroy_window (GtkWidget *window,
 
 static void
 dialog_button_clicked_cb (GtkDialog *dialog,
-			  int response_id,
-			  GConfChangeSet *changeset)
+			  int response_id)
 {
 	GError *error = NULL;
 	switch (response_id) {
@@ -125,12 +123,7 @@ dialog_button_clicked_cb (GtkDialog *dialog,
                 }
 	break;
 
-	case GTK_RESPONSE_APPLY:
-		gconf_client_commit_change_set (client, changeset, TRUE, NULL);
-		break;
-
 	default:
-		gconf_client_commit_change_set (client, changeset, TRUE, NULL);
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
 	}
@@ -145,7 +138,7 @@ no_info_toggled (GtkToggleButton *tb,
 	}
 
 	gtk_widget_set_sensitive (pd->name_box, FALSE);
-	gconf_change_set_set_int (changeset, "/apps/CDDB-Slave2/info", CDDB_SEND_FAKE_INFO);
+	gconf_client_set_int (client, "/apps/CDDB-Slave2/info", CDDB_SEND_FAKE_INFO, NULL);
 }
 
 static void
@@ -157,7 +150,7 @@ real_info_toggled (GtkToggleButton *tb,
 	}
 
 	gtk_widget_set_sensitive (pd->name_box, FALSE);
-	gconf_change_set_set_int (changeset, "/apps/CDDB-Slave2/info", CDDB_SEND_REAL_INFO);
+	gconf_client_set_int (client, "/apps/CDDB-Slave2/info", CDDB_SEND_REAL_INFO, NULL);
 }
 
 static void
@@ -169,23 +162,23 @@ specific_info_toggled (GtkToggleButton *tb,
 	}
 
 	gtk_widget_set_sensitive (pd->name_box, TRUE);
-	gconf_change_set_set_int (changeset, "/apps/CDDB-Slave2/info", CDDB_SEND_OTHER_INFO);
+	gconf_client_set_int (client, "/apps/CDDB-Slave2/info", CDDB_SEND_OTHER_INFO, NULL);
 }
 
 static void
 real_name_changed (GtkEntry *entry,
 		   PropertyDialog *pd)
 {
-	gconf_change_set_set_string (changeset, "/apps/CDDB-Slave2/name",
-				     gtk_entry_get_text (entry));
+	gconf_client_set_string (client, "/apps/CDDB-Slave2/name",
+				 gtk_entry_get_text (entry), NULL);
 }
 
 static void
 real_host_changed (GtkEntry *entry,
 		   PropertyDialog *pd)
 {
-	gconf_change_set_set_string (changeset, "/apps/CDDB-Slave2/hostname",
-				     gtk_entry_get_text (entry));
+	gconf_client_set_string (client, "/apps/CDDB-Slave2/hostname",
+				 gtk_entry_get_text (entry), NULL);
 }
 
 #define DEFAULT_SERVER "freedb.freedb.org"
@@ -201,9 +194,9 @@ round_robin_toggled (GtkToggleButton *tb,
 
 	gtk_widget_set_sensitive (pd->freedb_box, FALSE);
 	gtk_widget_set_sensitive (pd->other_box, FALSE);
-	gconf_change_set_set_int (changeset, "/apps/CDDB-Slave2/server-type", CDDB_ROUND_ROBIN);
-	gconf_change_set_set_string (changeset, "/apps/CDDB-Slave2/server", DEFAULT_SERVER);
-	gconf_change_set_set_int (changeset, "/apps/CDDB-Slave2/port", DEFAULT_PORT);
+	gconf_client_set_int (client, "/apps/CDDB-Slave2/server-type", CDDB_ROUND_ROBIN, NULL);
+	gconf_client_set_string (client, "/apps/CDDB-Slave2/server", DEFAULT_SERVER, NULL);
+	gconf_client_set_int (client, "/apps/CDDB-Slave2/port", DEFAULT_PORT, NULL);
 }
 
 static void
@@ -217,7 +210,7 @@ other_freedb_toggled (GtkToggleButton *tb,
 	gtk_widget_set_sensitive (pd->freedb_box, TRUE);
 	gtk_widget_set_sensitive (pd->other_box, FALSE);
 
-	gconf_change_set_set_int (changeset, "/apps/CDDB-Slave2/server-type", CDDB_OTHER_FREEDB);
+	gconf_client_set_int (client, "/apps/CDDB-Slave2/server-type", CDDB_OTHER_FREEDB, NULL);
 	/* Set it to the default selection */
 }
 
@@ -234,18 +227,18 @@ other_server_toggled (GtkToggleButton *tb,
 	gtk_widget_set_sensitive (pd->freedb_box, FALSE);
 	gtk_widget_set_sensitive (pd->other_box, TRUE);
 
-	gconf_change_set_set_int (changeset,
-				  "/apps/CDDB-Slave2/server-type", CDDB_OTHER_SERVER);
+	gconf_client_set_int (client,
+			      "/apps/CDDB-Slave2/server-type", CDDB_OTHER_SERVER, NULL);
 	str = gtk_entry_get_text (GTK_ENTRY (pd->other_host));
 	if (str != NULL) {
-		gconf_change_set_set_string (changeset,
-					     "/apps/CDDB-Slave2/server", str);
+		gconf_client_set_string (client,
+					 "/apps/CDDB-Slave2/server", str, NULL);
 	}
 
 	str = gtk_entry_get_text (GTK_ENTRY (pd->other_port));
 	if (str != NULL) {
-		gconf_change_set_set_int (changeset,
-					  "/apps/CDDB-Slave2/port", atoi (str));
+		gconf_client_set_int (client,
+				      "/apps/CDDB-Slave2/port", atoi (str), NULL);
 	}
 }
 
@@ -253,16 +246,16 @@ static void
 other_host_changed (GtkEntry *entry,
 		    PropertyDialog *pd)
 {
-	gconf_change_set_set_string (changeset, "/apps/CDDB-Slave2/server",
-				     gtk_entry_get_text (entry));
+	gconf_client_set_string (client, "/apps/CDDB-Slave2/server",
+				 gtk_entry_get_text (entry), NULL);
 }
 
 static void
 other_port_changed (GtkEntry *entry,
 		    PropertyDialog *pd)
 {
-	gconf_change_set_set_int (changeset, "/apps/CDDB-Slave2/port",
-				  atoi (gtk_entry_get_text (entry)));
+	gconf_client_set_int (client, "/apps/CDDB-Slave2/port",
+			      atoi (gtk_entry_get_text (entry)), NULL);
 }
 
 static void
@@ -620,8 +613,8 @@ server_selection_changed (GtkTreeSelection *selection,
 		char *port;
 
 		gtk_tree_model_get (model, &iter, 0, &server, 1, &port, -1);
-		gconf_change_set_set_string (changeset, "/apps/CDDB-Slave2/server", server);
-		gconf_change_set_set_int (changeset, "/apps/CDDB-Slave2/port", atoi (port));
+		gconf_client_set_string (client, "/apps/CDDB-Slave2/server", server, NULL);
+		gconf_client_set_int (client, "/apps/CDDB-Slave2/port", atoi (port), NULL);
 	}
 }
 
@@ -640,6 +633,35 @@ make_tree_model (void)
 	return GTK_TREE_MODEL (store);
 }
 
+static GtkWidget *
+hig_category_new (GtkWidget *parent, gchar *title, gboolean expand, gboolean fill)
+{
+	GtkWidget *vbox, *vbox2, *hbox;
+	GtkWidget *label;
+	gchar *tmp;
+	
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (parent), vbox, expand, fill, 0);
+
+	tmp = g_strdup_printf ("<b>%s</b>", _(title));
+	label = gtk_label_new (NULL);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+	gtk_label_set_markup (GTK_LABEL (label), tmp);
+	g_free (tmp);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
+
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+	vbox2 = gtk_vbox_new (FALSE, 6);
+	gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
+
+	return vbox2;
+}
+
 static void
 create_dialog (GtkWidget *window)
 {
@@ -648,8 +670,9 @@ create_dialog (GtkWidget *window)
 	GtkWidget *main_vbox;
 	GtkWidget *frame;
 	GtkWidget *align;
-	GtkWidget *vbox, *hbox;
+	GtkWidget *vbox, *hbox, *hbox2, *hbox3;
 	GtkWidget *label, *sw;
+	GtkWidget *icon;
 	GtkCellRenderer *cell;
 	GtkTreeViewColumn *col;
 	GtkTreeSelection *selection;
@@ -663,21 +686,20 @@ create_dialog (GtkWidget *window)
 	g_signal_connect (G_OBJECT (window), "destroy",
 			  G_CALLBACK (destroy_window), pd);
 
-	main_vbox = gtk_vbox_new (FALSE, 5);
+	main_vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_set_spacing (GTK_BOX (main_vbox), 18);
 	gtk_container_set_border_width (GTK_CONTAINER (main_vbox), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (window)->vbox), 2);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), main_vbox, TRUE, TRUE, 0);
 
 	/* Log on info */
-	frame = gtk_frame_new (_("Log on information"));
-	gtk_box_pack_start (GTK_BOX (main_vbox), frame, FALSE, FALSE, 0);
-
-	vbox = gtk_vbox_new (FALSE, 4);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+	frame = hig_category_new (main_vbox, _("Login Information"), FALSE, FALSE);
+	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
 
 	info = gconf_client_get_int (client, "/apps/CDDB-Slave2/info", NULL);
 	g_print ("info: %d\n", info);
-	pd->no_info = gtk_radio_button_new_with_mnemonic (NULL, _("Send _no information"));
+	pd->no_info = gtk_radio_button_new_with_mnemonic (NULL, _("Sen_d no information"));
 	if (info == CDDB_SEND_FAKE_INFO) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->no_info), TRUE);
 	}
@@ -695,7 +717,7 @@ create_dialog (GtkWidget *window)
 	gtk_box_pack_start (GTK_BOX (vbox), pd->real_info, FALSE, FALSE, 0);
 
 	pd->specific_info = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (pd->real_info),
-									    _("Send _other information..."));
+									    _("Send _other information:"));
 	if (info == CDDB_SEND_OTHER_INFO) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pd->specific_info), TRUE);
 	}
@@ -704,15 +726,23 @@ create_dialog (GtkWidget *window)
 			  G_CALLBACK (specific_info_toggled), pd);
 	gtk_box_pack_start (GTK_BOX (vbox), pd->specific_info, FALSE, FALSE, 0);
 
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
 	pd->name_box = gtk_table_new (2, 2, FALSE);
+	gtk_table_set_row_spacings (GTK_TABLE (pd->name_box), 6);
+	gtk_table_set_col_spacings (GTK_TABLE (pd->name_box), 12);
 	if (info != CDDB_SEND_OTHER_INFO) {
 		gtk_widget_set_sensitive (pd->name_box, FALSE);
 	}
 	
-	gtk_box_pack_start (GTK_BOX (vbox), pd->name_box, FALSE, FALSE, 0);
-	
-	align = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
-	label = gtk_label_new_with_mnemonic (_("N_ame:"));
+	gtk_box_pack_start (GTK_BOX (hbox), pd->name_box, TRUE, TRUE, 0);
+
+	align = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
+	label = gtk_label_new_with_mnemonic (_("_Name:"));
 	gtk_container_add (GTK_CONTAINER (align), label);
 	gtk_table_attach (GTK_TABLE (pd->name_box), align,
 			  0, 1, 0, 1, GTK_FILL, GTK_FILL,
@@ -730,9 +760,9 @@ create_dialog (GtkWidget *window)
 	gtk_table_attach (GTK_TABLE (pd->name_box), pd->real_name,
 			  1, 2, 0, 1, GTK_FILL | GTK_EXPAND, GTK_FILL,
 			  0, 0);
-
-	align = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
-	label = gtk_label_new_with_mnemonic (_("_Hostname:"));
+	
+	align = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
+	label = gtk_label_new_with_mnemonic (_("Hostna_me:"));
 	gtk_container_add (GTK_CONTAINER (align), label);
 	gtk_table_attach (GTK_TABLE (pd->name_box), align,
 			  0, 1, 1, 2, GTK_FILL, GTK_FILL,
@@ -751,15 +781,10 @@ create_dialog (GtkWidget *window)
 			  1, 2, 1, 2, GTK_FILL | GTK_EXPAND, GTK_FILL,
 			  0, 0);
 
-	gtk_table_set_row_spacings (GTK_TABLE (pd->name_box), GNOME_PAD_SMALL);
-	gtk_table_set_col_spacings (GTK_TABLE (pd->name_box), GNOME_PAD_SMALL);
-
 	/* Server info */
-	frame = gtk_frame_new (_("Server"));
-	gtk_box_pack_start (GTK_BOX (main_vbox), frame, TRUE, TRUE, 0);
+	frame = hig_category_new (main_vbox, _("Server"), TRUE, TRUE);
 
-	vbox = gtk_vbox_new (FALSE, 4);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
 
 	info = gconf_client_get_int (client, "/apps/CDDB-Slave2/server-type", NULL);
@@ -769,14 +794,20 @@ create_dialog (GtkWidget *window)
 	gtk_box_pack_start (GTK_BOX (vbox), pd->round_robin, FALSE, FALSE, 0);
 
 	pd->other_freedb = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (pd->round_robin),
-									   _("Other _FreeDB server..."));
+									   _("Other _FreeDB server:"));
 	g_signal_connect (G_OBJECT (pd->other_freedb), "toggled",
 			  G_CALLBACK (other_freedb_toggled), pd);
 	gtk_box_pack_start (GTK_BOX (vbox), pd->other_freedb, FALSE, FALSE, 0);
 
-	pd->freedb_box = gtk_vbox_new (FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
+	
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	
+	pd->freedb_box = gtk_vbox_new (FALSE, 6);
 	gtk_widget_set_sensitive (pd->freedb_box, FALSE);
-	gtk_box_pack_start (GTK_BOX (vbox), pd->freedb_box, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), pd->freedb_box, TRUE, TRUE, 0);
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
@@ -807,14 +838,40 @@ create_dialog (GtkWidget *window)
 	
 	gtk_container_add (GTK_CONTAINER (sw), pd->freedb_server);
 
-	pd->update = gtk_button_new_with_label (_("Update server list"));
 	g_signal_connect (G_OBJECT (pd->update), "clicked",
 			  G_CALLBACK (update_clicked), pd);
-	
-	gtk_box_pack_start (GTK_BOX (pd->freedb_box), pd->update, FALSE, FALSE, 2);
+
+	/* create the update server list button */
+	align = gtk_alignment_new (1.0, 0.5, 0.0, 0.0);
+
+	pd->update = gtk_button_new ();
+ 	g_signal_connect (G_OBJECT (pd->update), "clicked",
+ 			  G_CALLBACK (update_clicked), pd);
+
+	gtk_container_add (GTK_CONTAINER (align), pd->update);
+ 	
+	gtk_box_pack_start (GTK_BOX (pd->freedb_box), align, FALSE, FALSE, 0);
+
+	/* ... and it's contents */
+	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+	gtk_container_add (GTK_CONTAINER (pd->update), align);
+
+	hbox = gtk_hbox_new (FALSE, 2);
+
+	gtk_container_add (GTK_CONTAINER (align), hbox);
+
+	icon = gtk_image_new_from_stock (GTK_STOCK_REFRESH, GTK_ICON_SIZE_BUTTON);
+
+	gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
+
+	label = gtk_label_new_with_mnemonic (_("_Update Server List"));
+
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pd->update);
+
+	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	pd->other_server = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (pd->other_freedb),
-									   _("Other _server..."));
+									   _("Other _server:"));
 	g_signal_connect (G_OBJECT (pd->other_server), "toggled",
 			  G_CALLBACK (other_server_toggled), pd);
 	gtk_box_pack_start (GTK_BOX (vbox), pd->other_server, FALSE, FALSE, 0);
@@ -823,13 +880,22 @@ create_dialog (GtkWidget *window)
 	gtk_widget_set_sensitive (pd->other_box, FALSE);
 	gtk_box_pack_start (GTK_BOX (vbox), pd->other_box, FALSE, FALSE, 0);
 
-	hbox = gtk_hbox_new (FALSE, 4);
-	gtk_box_pack_start (GTK_BOX (pd->other_box), hbox, TRUE, TRUE, 0);
+	hbox3 = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (pd->other_box), hbox3, FALSE, FALSE, 0);
 	
-	label = gtk_label_new (_("Hostname:"));
+	label = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (hbox3), label, FALSE, FALSE, 0);	
+
+	hbox2 = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (hbox3), hbox2, FALSE, FALSE, 0);
+	
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (hbox2), hbox, FALSE, FALSE, 0);
+	label = gtk_label_new_with_mnemonic (_("Hos_tname:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	pd->other_host = gtk_entry_new ();
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pd->other_host);
 	g_signal_connect (G_OBJECT (pd->other_host), "changed",
 			  G_CALLBACK (other_host_changed), pd);
 	str = gconf_client_get_string (client, "/apps/CDDB-Slave2/server", NULL);
@@ -839,9 +905,11 @@ create_dialog (GtkWidget *window)
 	}
 	gtk_box_pack_start (GTK_BOX (hbox), pd->other_host, TRUE, TRUE, 0);
 
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (hbox2), hbox, FALSE, FALSE, 0);
+
 	label = gtk_label_new_with_mnemonic (_("_Port:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
 	pd->other_port = gtk_entry_new ();
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), pd->other_port);
 	g_signal_connect (G_OBJECT (pd->other_port), "changed",
@@ -870,12 +938,29 @@ create_dialog (GtkWidget *window)
 		break;
 	}
 }
+
+static GdkPixbuf *
+pixbuf_from_file (const char *filename)
+{
+	GdkPixbuf *pixbuf;
+	char *fullname;
+
+	fullname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+                   filename, TRUE, NULL);
+	g_return_val_if_fail (fullname != NULL, NULL);
+
+	pixbuf = gdk_pixbuf_new_from_file (fullname, NULL);
+	g_free (fullname);
+
+	return pixbuf;
+}
 	
 int
 main (int argc,
       char **argv)
 {
 	GtkWidget *dialog_win;
+	GdkPixbuf *pixbuf;
 	
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -887,26 +972,33 @@ main (int argc,
 	gconf_client_add_dir (client, "/apps/CDDB-Slave2",
 			      GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
-	changeset = gconf_change_set_new ();
-
 	dialog_win = gtk_dialog_new_with_buttons (_("CD Database Preferences"),
 						  NULL, -1,
 						  GTK_STOCK_HELP, GTK_RESPONSE_HELP,
-						  GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
 						  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 						  NULL);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dialog_win), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (dialog_win), 5);
+
 	gtk_window_set_default_size (GTK_WINDOW (dialog_win), 440, 570);
 	create_dialog (dialog_win);
 
 	gtk_dialog_set_default_response(GTK_DIALOG (dialog_win), GTK_RESPONSE_CLOSE);
 
   	g_signal_connect (G_OBJECT (dialog_win), "response",
-  			  G_CALLBACK (dialog_button_clicked_cb), changeset);
+  			  G_CALLBACK (dialog_button_clicked_cb), NULL);
+
+	pixbuf = pixbuf_from_file ("gnome-cd/cd.png");
+	if (pixbuf == NULL) {
+		g_warning ("Error finding gnome-cd/cd.png");
+	} else {
+		gtk_window_set_icon (GTK_WINDOW (dialog_win), pixbuf);
+		g_object_unref (G_OBJECT (pixbuf));
+	}
 
 	gtk_widget_show_all (dialog_win);
 
 	gtk_main ();
-	gconf_change_set_unref (changeset);
 
 	return 0;
 }
