@@ -225,7 +225,7 @@ static void
 do_goodbye (ConnectionData *cd)
 {
 	char *quit;
-	gsize bytes_writen;
+	guint bytes_writen;
 	GIOError status;
 	
 	/* Send quit command */
@@ -383,7 +383,7 @@ do_read (ConnectionData *cd,
 	 const char *dtitle)
 {
 	char *query;
-	gsize bytes_writen;
+	guint bytes_writen;
 	GIOError status;
 	
 	/* Send read command */
@@ -674,7 +674,7 @@ static void
 do_query (ConnectionData *cd)
 {
 	char *query;
-	gsize bytes_writen;
+	guint bytes_writen;
 	GIOError status;
 	
 	/* Send query command */
@@ -744,7 +744,7 @@ static void
 do_hello (ConnectionData *cd)
 {
 	char *hello;
-	gsize bytes_writen;
+	guint bytes_writen;
 	GIOError status;
 	
 	/* Send the Hello command
@@ -1453,7 +1453,7 @@ impl_GNOME_Media_CDDBSlave2_setYear (PortableServer_Servant servant,
 
 	dyear = g_hash_table_lookup (entry->fields, "DYEAR");
 	if (dyear == NULL) {
-		dyear = g_string_new ("");
+		dyear = g_string_new (NULL);
 		g_string_printf (dyear, "%d", year);
 		g_hash_table_insert (entry->fields, g_strdup ("DYEAR"), dyear);
 	} else {
