@@ -118,7 +118,8 @@ cddb_free_disc_info (GnomeCDDiscInfo *info)
 	g_free (info->title);
 	g_free (info->artist);
 
-	cddb_slave_client_free_track_info (info->track_info);
+	if (info->track_info)
+		cddb_slave_client_free_track_info (info->track_info);
 	g_free (info);
 }
 
@@ -185,6 +186,8 @@ cddb_get_query (GnomeCD *gcd)
 	} else {
 		info = cddb_make_disc_info (data);
 		g_hash_table_insert (cddb_cache, info->discid, info);
+		gcd->disc_info = info;
+		gnome_cd_build_track_list_menu (gcd);
 	}
 
 	/* Remove the last space */
