@@ -25,41 +25,23 @@
 
 #include <config.h>
 
-typedef enum _GnomeCDPreferencesStart {
-	GNOME_CD_PREFERENCES_START_NOTHING,
-	GNOME_CD_PREFERENCES_START_START,
-	GNOME_CD_PREFERENCES_START_STOP
-} GnomeCDPreferencesStart;
-
-typedef enum _GnomeCDPreferencesStop {
-	GNOME_CD_PREFERENCES_STOP_NOTHING,
-	GNOME_CD_PREFERENCES_STOP_STOP,
-	GNOME_CD_PREFERENCES_STOP_OPEN,
-#ifdef HAVE_CDROMCLOSETRAY_IOCTL
-	GNOME_CD_PREFERENCES_STOP_CLOSE
-#endif
-} GnomeCDPreferencesStop;
-
 typedef struct _GnomeCDPreferences {
 	GnomeCD *gcd;
 	char *device;
 	char *theme_name;
 	
-	GnomeCDPreferencesStart start;
-#ifdef HAVE_CDROMCLOSETRAY_IOCTL
-	gboolean start_close;
-#endif
-
-	GnomeCDPreferencesStop stop;
-
+	gboolean start_play;
+	gboolean stop_eject;
+	
 	/* GConf IDs */
 	guint device_id;
 	guint start_id;
-#ifdef HAVE_CDROMCLOSETRAY_IOCTL
-	guint close_id;
-#endif
 	guint stop_id;
 	guint theme_id;
 } GnomeCDPreferences;
 
+GnomeCDPreferences *preferences_new         (GnomeCD *gcd);
+GtkWidget          *preferences_dialog_show (GnomeCD *gcd,
+					     gboolean only_device);
+
 #endif
