@@ -93,7 +93,7 @@ gsr_open_window (const char *filename)
 		name = g_strdup (filename);
 	}
 
-	window = gsr_window_new (name);
+	window = GTK_WIDGET (gsr_window_new (name));
 	g_free (name);
 	g_signal_connect (G_OBJECT (window), "destroy",
 			  G_CALLBACK (window_destroyed), NULL);
@@ -167,8 +167,10 @@ main (int argc,
 				      GNOME_PARAM_APP_DATADIR, DATADIR,
 				      NULL);
 
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-audio2.png");
 	/* Init GStreamer */
 	gst_init (&argc, &argv);
+	gst_scheduler_factory_set_default_name ("basicomega");
 
 	/* Init the icons */
 	init_stock_icons ();
